@@ -217,12 +217,12 @@ QStringList Datenbank::findByTagList(const QStringList &mustHave, const QStringL
     		   " ( SELECT DISTINCT bildid"
 		     " FROM tags WHERE"
 		     " tag IN"
-		     " ( "; 
+		     " ( ?"; 
     		     
-    for(i=0; i<notHave.size(); i++) {
-      if(0 != i)
-	queryString += ',';
-      queryString += '?';
+    // Always at least one item.
+    // That has already been checked and handled.
+    for(i=1; i<notHave.size(); i++) {
+      queryString += ",?";
     }
     queryString +=   " )"
 		   ")";
@@ -270,7 +270,10 @@ QStringList Datenbank::getAllTags() const {
 }
 
 /*!
+  \~german
   \return Liste aller bekannten Bilder.
+  \~english
+  \return List of all known images
 */ 
 QStringList Datenbank::getAllImages() const {
   QStringList ret;
