@@ -26,6 +26,7 @@
 #include <QCompleter>
 #include <QDir>
 #include <QSettings>
+#include <QWhatsThis>
 #include <iostream>
 
 /*!
@@ -43,14 +44,22 @@ MainWin::MainWin(QWidget *p)
   m_bildauswahl = new Bildauswahl(this);
   addToolBar(Qt::TopToolBarArea, m_bildauswahl);
 
+  m_ui.menuHilfe->insertAction(m_ui.actionAbout, QWhatsThis::createAction(m_ui.menuHilfe));
+  m_ui.menuHilfe->insertSeparator(m_ui.actionAbout);
   QSettings settings;
 
   QObject::connect(m_ui.actionNeu, SIGNAL(triggered()),
 	this, SLOT(newPicture()));
+  QObject::connect(m_ui.actionNeue_Bilder, SIGNAL(triggered()),
+	this, SLOT(findNewPictures()));
   QObject::connect(m_ui.actionSpeichern, SIGNAL(triggered()),
 	this, SLOT(saveData()));
   QObject::connect(m_ui.actionSuchen, SIGNAL(triggered()),
 	this, SLOT(search()));
+  QObject::connect(m_ui.actionAbout, SIGNAL(triggered()),
+	this, SLOT(about()));
+  QObject::connect(m_ui.actionAboutQT, SIGNAL(triggered()),
+	qApp, SLOT(aboutQt()));
   QObject::connect(m_ui.actionOptionen, SIGNAL(triggered()),
 	this, SLOT(options()));
   QObject::connect(m_ui.ZoomIn, SIGNAL(clicked()),
@@ -195,6 +204,51 @@ void MainWin::displayPicture(const QString &bildName) {
   m_dirty = false;
 }
 
+/*!
+  Sucht in einem Verzeichnis nach Bildern, die noch nicht in der Datenbank sind.
+*/ 
+void MainWin::findNewPictures() {
+  QStringList newImages;
+
+  QString pathName = QFileDialog::getExistingDirectory(this, tr("Bilderpfad"), m_path);
+  if("" != pathName) {
+    QDir path(pathName);
+    QStringList bildtyp;
+    bildtyp << "*.png" << "*.jpg" <<  "*.jpeg" << "*.xpm" <<  "*.gif";
+    QStringList dirBilder = path.entryList(bildtyp, QDir::Files|QDir::Readable, QDir::Name);
+    if(!dirBilder.empty()) {
+      QStringList alleBilder = m_datenbank->getAllImages();
+      alleBilder.sort();
+
+      int i=0, j=0;
+      while(i<dirBilder.size() && j < alleBilder.size()) {
+        if(!dirBilder[i].startsWith(pathName)) 
+          dirBilder[i] = pathName + dirBilder[i];
+        if(dirBilder[i] < alleBilder[j]) {
+	  newImages << dirBilder[i++];
+	} else if(dirBilder[i] > alleBilder[j]) {
+	  j++;
+	} else {
+	  i++;
+	  j++;
+	}
+      }
+      while(i<dirBilder.size()) { // Noch Bilder uebrig?
+        if(!dirBilder[i].startsWith(pathName)) 
+          dirBilder[i] = pathName + dirBilder[i];
+        newImages << dirBilder[i++];
+      }
+    }
+  }
+
+  if(newImages.empty()) {
+    QMessageBox::information(this, tr("Suche"), tr("keine neuen Bilder gefunden"));
+  } else {
+    newPictureList(newImages);
+  }
+
+}
+
 /*!
   \~german
   Tags zum Bild in die Datenbank schreiben
@@ -214,6 +268,22 @@ void MainWin::saveData() {
   m_dirty = false;
 }
 
+/*!
+  About Informationen anzeigen
+*/ 
+void MainWin::about() {
+  QMessageBox::about(this, tr("Ueber imageTagger"),
+    tr("imageTagger ist ein einfaches Programm zum organisieren von "
+       "Bildersammlungen ueber Tags."
+       "<p>"
+       "&copy;2008 <a href=\"mailto:bretscher@5sl.org\">Johannes Bretscher</a>"
+       "<p>"
+       "This program is distributed in the hope that it will be useful, "
+    "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
+    "GNU General Public License for more details. "));
+}
+
 /*!
   \~german
   Bildanzeige vergroessern
@@ -312,7 +382,7 @@ void MainWin::options() {
 }
 /*!
   \~german Durch Laden oder Bildsuche hat sich die Liste der Bilder geaendert.
-  \~english Imge list has changed
+  \~english Image list has changed
 */
 void MainWin::newPictureList(const QStringList &list) {
   // std::cerr << "Piclist" << std::endl;
