@@ -30,6 +30,7 @@
 #include "tagsuche.h"
 #include "optionen.h"
 
+
 /*!
   \brief Das Hauptfenster mit einer Darstellung des Spielfeldes
 */
@@ -43,21 +44,28 @@ class MainWin : public QMainWindow {
   Bildauswahl *m_bildauswahl;	//!< Verwaltungsleiste der Bilderliste
   bool m_dirty;	//!< Tags zu aktuellem Bild wurden geaendert.
   Tagsuche *m_tagsuche;	//!< Fenster zur Suche nach bestimmten Tags
+  DisplayMode m_defaultDisplayMode;
 
   public:
   MainWin(QWidget* =0);
 
   private slots:
   void newPicture();
+  void findNewPictures();
   void saveData();
+  void about();
   void zoomIn();
   void zoomOut();
+  void zoomOriginal();
+  void fitWidth();
+  void fitHeight();
   void newTag();
   void displayPicture(const QString&);
   void setDirty();
   void search();
   void newPictureList(const QStringList &);
   void options();
+  void changeDefaultZoom(DisplayMode);
   
 
   private:
